==> android-4.0.1.2-sources.jar: android/graphics/Typeface.java <==
package android.graphics;
public class Typeface
{
Typeface() { throw new RuntimeException("Stub!"); }
public  int getStyle() { throw new RuntimeException("Stub!"); }
public final  boolean isBold() { throw new RuntimeException("Stub!"); }
public final  boolean isItalic() { throw new RuntimeException("Stub!"); }
public static  android.graphics.Typeface create(java.lang.String familyName, int style) { throw new RuntimeException("Stub!"); }
public static  android.graphics.Typeface create(android.graphics.Typeface family, int style) { throw new RuntimeException("Stub!"); }
public static  android.graphics.Typeface defaultFromStyle(int style) { throw new RuntimeException("Stub!"); }
public static  android.graphics.Typeface createFromAsset(android.content.res.AssetManager mgr, java.lang.String path) { throw new RuntimeException("Stub!"); }
public static  android.graphics.Typeface createFromFile(java.io.File path) { throw new RuntimeException("Stub!"); }
public static  android.graphics.Typeface createFromFile(java.lang.String path) { throw new RuntimeException("Stub!"); }
protected  void finalize() throws java.lang.Throwable { throw new RuntimeException("Stub!"); }
public static final android.graphics.Typeface DEFAULT;
public static final android.graphics.Typeface DEFAULT_BOLD;
public static final android.graphics.Typeface SANS_SERIF;
public static final android.graphics.Typeface SERIF;
public static final android.graphics.Typeface MONOSPACE;
public static final int NORMAL = 0;
public static final int BOLD = 1;
public static final int ITALIC = 2;
public static final int BOLD_ITALIC = 3;
static { DEFAULT = null; DEFAULT_BOLD = null; SANS_SERIF = null; SERIF = null; MONOSPACE = null; }
}

==> android-4.1.1.4-sources.jar: android/graphics/Typeface.java <==
package android.graphics;
public class Typeface
{
Typeface() { throw new RuntimeException("Stub!"); }
public  int getStyle() { throw new RuntimeException("Stub!"); }
public final  boolean isBold() { throw new RuntimeException("Stub!"); }
public final  boolean isItalic() { throw new RuntimeException("Stub!"); }
public static  android.graphics.Typeface create(java.lang.String familyName, int style) { throw new RuntimeException("Stub!"); }
public static  android.graphics.Typeface create(android.graphics.Typeface family, int style) { throw new RuntimeException("Stub!"); }
public static  android.graphics.Typeface defaultFromStyle(int style) { throw new RuntimeException("Stub!"); }
public static  android.graphics.Typeface createFromAsset(android.content.res.AssetManager mgr, java.lang.String path) { throw new RuntimeException("Stub!"); }
public static  android.graphics.Typeface createFromFile(java.io.File path) { throw new RuntimeException("Stub!"); }
public static  android.graphics.Typeface createFromFile(java.lang.String path) { throw new RuntimeException("Stub!"); }
protected  void finalize() throws java.lang.Throwable { throw new RuntimeException("Stub!"); }
public  boolean equals(java.lang.Object o) { throw new RuntimeException("Stub!"); }
public  int hashCode() { throw new RuntimeException("Stub!"); }
public static final android.graphics.Typeface DEFAULT;
public static final android.graphics.Typeface DEFAULT_BOLD;
public static final android.graphics.Typeface SANS_SERIF;
public static final android.graphics.Typeface SERIF;
public static final android.graphics.Typeface MONOSPACE;
public static final int NORMAL = 0;
public static final int BOLD = 1;
public static final int ITALIC = 2;
public static final int BOLD_ITALIC = 3;
static { DEFAULT = null; DEFAULT_BOLD = null; SANS_SERIF = null; SERIF = null; MONOSPACE = null; }
}
